@@ -115,7 +115,6 @@ reverse.numeric <- function(x,
 }
 
 
-
 #' @export
 reverse.factor <- function(x, range = NULL, verbose = TRUE, ...) {
   # Warning if all NaNs
@@ -186,7 +185,7 @@ reverse.factor <- function(x, range = NULL, verbose = TRUE, ...) {
 
   int_x <- as.integer(x)
   rev_x <- reverse(int_x, range = c(1, length(old_levels)))
-  x <- factor(rev_x, levels = seq_len(length(old_levels)), labels = old_levels)
+  x <- factor(rev_x, levels = seq_along(old_levels), labels = old_levels)
 
   # labelled data?
   x <- .set_back_labels(x, original_x, reverse_values = TRUE)
@@ -195,7 +194,6 @@ reverse.factor <- function(x, range = NULL, verbose = TRUE, ...) {
 }
 
 
-
 #' @export
 reverse.grouped_df <- function(x,
                                select = NULL,
@@ -254,7 +252,6 @@ reverse.grouped_df <- function(x,
 }
 
 
-
 #' @rdname reverse
 #' @export
 reverse.data.frame <- function(x,
