@@ -75,7 +75,7 @@ coef_var.default <- function(x, verbose = TRUE, ...) {
 #'   each end of `x` before the mean and standard deviation (or other measures)
 #'   are computed. Values of `trim` outside the range of (0 to 0.5) are taken
 #'   as the nearest endpoint.
-#' @param na.rm Logical. Should `NA` values be removed before computing (`TRUE`)
+#' @param remove_na Logical. Should `NA` values be removed before computing (`TRUE`)
 #'   or not (`FALSE`, default)?
 #' @param n If `method = "unbiased"` and both `mu` and `sigma` are provided (not
 #'   computed from `x`), what sample size to use to adjust the computed CV
@@ -110,14 +110,14 @@ coef_var.default <- function(x, verbose = TRUE, ...) {
 #' @export
 coef_var.numeric <- function(x, mu = NULL, sigma = NULL,
                              method = c("standard", "unbiased", "median_mad", "qcd"),
-                             trim = 0, na.rm = FALSE, n = NULL, ...) {
+                             trim = 0, remove_na = FALSE, n = NULL, ...) {
   # TODO: Support weights
   if (!missing(x) && all(c(-1, 1) %in% sign(x))) {
     insight::format_error("Coefficient of variation only applicable for ratio scale variables.")
   }
   method <- match.arg(method, choices = c("standard", "unbiased", "median_mad", "qcd"))
   if (is.null(mu) || is.null(sigma)) {
-    if (isTRUE(na.rm)) {
+    if (isTRUE(remove_na)) {
       x <- .drop_na(x)
     }
     n <- length(x)
@@ -149,12 +149,10 @@ coef_var.numeric <- function(x, mu = NULL, sigma = NULL,
     # from DescTools::CoefVar
     out <- out * (1 - 1 / (4 * (n - 1)) + 1 / n * out^2 + 1 / (2 * (n - 1)^2))
   }
-  return(out)
+  out
 }
 
 
-
-
 # descriptives helpers
 
 .drop_na <- function(x) {
