@@ -23,7 +23,7 @@
 #'
 #' @details For character vectors, empty string values (i.e. `""`) are also
 #' considered as missing value. Thus, if a character vector only contains `NA`
-#' and `""``, it is considered as empty variable and will be removed. Same
+#' and `""`, it is considered as empty variable and will be removed. Same
 #' applies to observations (rows) that only contain `NA` or `""`.
 #'
 #' @examples
@@ -63,7 +63,7 @@ empty_columns <- function(x) {
   } else {
     all_na <- colSums(is.na(x)) == nrow(x)
     all_empty <- vapply(x, function(i) {
-      (is.character(i) || is.factor(i)) && max(c(0, nchar(as.character(i))), na.rm = TRUE) == 0
+      (is.character(i) || is.factor(i)) && !any(nzchar(as.character(i[!is.na(i)])))
     }, FUN.VALUE = logical(1L))
 
     which(all_na | all_empty)
@@ -77,7 +77,7 @@ empty_rows <- function(x) {
   if ((!is.matrix(x) && !is.data.frame(x)) || nrow(x) < 2) {
     vector("numeric")
   } else {
-    which(rowSums((is.na(x) | x == "")) == ncol(x))
+    which(rowSums((is.na(x) | x == "")) == ncol(x)) # nolint
   }
 }
 
